@@ -16,6 +16,7 @@
 #' @param pct_type Controls the kind of percentage values returned. One of "row" or "cell."
 #' @param format one of "long" or "wide"
 #' @param zscore defaults to 1.96, consistent with a 95\% confidence interval
+#' @param unwt_n logical, if TRUE it adds a column with unweighted frequency values
 #'
 #' @return a tibble
 #' @export
@@ -32,7 +33,9 @@
 
 moe_crosstab_3way <- function(df, x, y, z,
                               weight, remove = c(""),
-                              n = TRUE, pct_type = "row", format = "long", zscore = 1.96){
+                              n = TRUE, pct_type = "row",
+                              format = "long", zscore = 1.96,
+                              unwt_n = FALSE){
   # make sure the arguments are all correct
   stopifnot(pct_type %in% c("row", "cell"),
             format %in% c("wide", "long"))
@@ -51,13 +54,14 @@ moe_crosstab_3way <- function(df, x, y, z,
              {{z}} := to_factor({{z}})) %>%
       group_by({{z}}, {{x}}) %>%
       mutate(total = sum({{weight}}),
-             n = length({{weight}})) %>%
+             unweighted_n = length({{weight}})) %>%
       group_by({{z}}, {{x}}, {{y}}) %>%
       summarise(observations = sum({{weight}}),
                 pct = observations/first(total),
-                n = first(n)) %>%
+                n = first(total),
+                unweighted_n = first(unweighted_n)) %>%
       ungroup() %>%
-      mutate(moe = moedeff_calc(pct = pct, deff = deff, n = n, zscore = zscore)) %>%
+      mutate(moe = moedeff_calc(pct = pct, deff = deff, n = unweighted_n, zscore = zscore)) %>%
       mutate(pct = pct*100) %>%
       select(-observations) %>%
       # Remove values included in "remove" string
@@ -65,7 +69,7 @@ moe_crosstab_3way <- function(df, x, y, z,
              !str_to_upper({{y}}) %in% str_to_upper(remove),
              !str_to_upper({{z}}) %in% str_to_upper(remove)) %>%
       # move total row to end
-      select(-one_of("n"), one_of("n"))
+      select(-one_of("n", "unweighted_n"), one_of("n", "unweighted_n"))
   } else if(pct_type == "cell"){
     d.output <- df %>%
       filter(!is.na({{x}}),
@@ -75,26 +79,29 @@ moe_crosstab_3way <- function(df, x, y, z,
       # calculate denominator
       group_by({{z}}) %>%
       mutate(total = sum({{weight}}),
-             n = length({{weight}})) %>%
+             unweighted_n = length({{weight}})) %>%
       group_by({{z}}, {{x}}, {{y}}) %>%
       summarise(observations = sum({{weight}}),
                 pct = observations/first(total),
-                n = first(n)) %>%
+                n = first(total),
+                unweighted_n = first(unweighted_n)) %>%
       ungroup() %>%
-      mutate(moe = moedeff_calc(pct = pct, deff = deff, n = n, zscore = zscore)) %>%
+      mutate(moe = moedeff_calc(pct = pct, deff = deff, n = unweighted_n, zscore = zscore)) %>%
       mutate(pct = pct*100) %>%
       select(-observations) %>%
       # Remove values included in "remove" string
       filter(!str_to_upper({{x}}) %in% str_to_upper(remove),
              !str_to_upper({{y}}) %in% str_to_upper(remove)) %>%
       # move total row to end
-      select(-one_of("n"), one_of("n"))
+      select(-one_of("n", "unweighted_n"), one_of("n", "unweighted_n"))
   }
 
   # convert to wide format if required
   if(format == "wide"){
     d.output <- d.output %>%
-      pivot_wider(names_from = {{y}}, values_from = c(pct, moe), values_fill = list(pct = 0, moe = 0))
+      pivot_wider(names_from = {{y}}, values_from = c(pct, moe),
+                  values_fill = list(pct = 0, moe = 0)) %>%
+      select(-one_of("n", "unweighted_n"), one_of("n", "unweighted_n"))
   }
 
   # remove n if required
@@ -102,6 +109,11 @@ moe_crosstab_3way <- function(df, x, y, z,
     d.output <- select(d.output, -n)
   }
 
+  # remove unweighted_n if required
+  if(unwt_n == FALSE){
+    d.output <- select(d.output, -unweighted_n)
+  }
+
   # test if date or number
   factor.true.type <- what_is_this_factor(pull(d.output, {{z}}))
   if(factor.true.type == "date"){
