@@ -19,6 +19,7 @@
 #' Column percents are not supported.
 #' @param format one of "long" or "wide"
 #' @param zscore defaults to 1.96, consistent with a 95\% confidence interval
+#' @param unwt_n logical, if TRUE it adds a column with unweighted frequency values
 #'
 #' @return a tibble
 #' @export
@@ -33,7 +34,8 @@
 #' moe_wave_crosstab(df = illinois, x = year, y = maritalstatus, weight = weight, format = "wide")
 
 moe_wave_crosstab <- function(df, x, y, weight, remove = c(""), n = TRUE,
-                              pct_type = "row", format = "long", zscore = 1.96){
+                              pct_type = "row", format = "long",
+                              zscore = 1.96, unwt_n = FALSE){
 
   # make sure the arguments are all correct
   stopifnot(pct_type %in% c("row", "cell"),
@@ -57,21 +59,22 @@ moe_wave_crosstab <- function(df, x, y, weight, remove = c(""), n = TRUE,
              {{y}} := to_factor({{y}})) %>%
       group_by({{x}}) %>%
       mutate(total = sum({{weight}}),
-             n = length({{weight}})) %>%
+             unweighted_n = length({{weight}})) %>%
       group_by({{x}}, {{y}}) %>%
       summarise(observations = sum({{weight}}),
                 pct = observations/first(total),
-                n = first(n)) %>%
+                n = first(total),
+                unweighted_n = first(unweighted_n)) %>%
       ungroup() %>%
       inner_join(stats.by.wave) %>%
-      mutate(moe = moedeff_calc(pct = pct, deff = deff, n = n, zscore = zscore)) %>%
+      mutate(moe = moedeff_calc(pct = pct, deff = deff, n = unweighted_n, zscore = zscore)) %>%
       mutate(pct = pct*100) %>%
       select(-observations) %>%
       # Remove values included in "remove" string
       filter(!str_to_upper({{x}}) %in% str_to_upper(remove),
              !str_to_upper({{y}}) %in% str_to_upper(remove)) %>%
       # move total row to end
-      select(-one_of("n"), one_of("n")) %>%
+      select(-one_of("n", "unweighted_n"), one_of("n", "unweighted_n")) %>%
       select(-deff)
   } else if(pct_type == "cell"){
     d.output <- df %>%
@@ -81,34 +84,41 @@ moe_wave_crosstab <- function(df, x, y, weight, remove = c(""), n = TRUE,
              {{y}} := to_factor({{y}})) %>%
       # calculate denominator
       mutate(total = sum({{weight}}),
-             n = length({{weight}})) %>%
+             unweighted_n = length({{weight}})) %>%
       group_by({{x}}, {{y}}) %>%
       summarise(observations = sum({{weight}}),
                 pct = observations/first(total),
-                n = first(n)) %>%
+                n = first(total),
+                unweighted_n = first(unweighted_n)) %>%
       ungroup() %>%
       inner_join(stats.by.wave) %>%
-      mutate(moe = moedeff_calc(pct = pct, deff = deff, n = n, zscore = zscore)) %>%
+      mutate(moe = moedeff_calc(pct = pct, deff = deff, n = unweighted_n, zscore = zscore)) %>%
       mutate(pct = pct*100) %>%
       select(-observations) %>%
       # Remove values included in "remove" string
       filter(!str_to_upper({{x}}) %in% str_to_upper(remove),
              !str_to_upper({{y}}) %in% str_to_upper(remove)) %>%
       # move total row to end
-      select(-one_of("n"), one_of("n")) %>%
+      select(-one_of("n", "unweighted_n"), one_of("n", "unweighted_n")) %>%
       select(-deff)
   }
 
   # convert to wide format if required
   if(format == "wide"){
     d.output <- d.output %>%
-      pivot_wider(names_from = {{y}}, values_from = c(pct, moe), values_fill = list(pct = 0, moe = 0))
+      pivot_wider(names_from = {{y}}, values_from = c(pct, moe),
+                  values_fill = list(pct = 0, moe = 0)) %>%
+      select(-one_of("n", "unweighted_n"), one_of("n", "unweighted_n"))
   }
 
   # remove n if required
   if(n == FALSE){
     d.output <- select(d.output, -n)
   }
+  # remove unweighted_n if required
+  if(unwt_n == FALSE){
+    d.output <- select(d.output, -unweighted_n)
+  }
 
   # test if date or number
   factor.true.type <- what_is_this_factor(pull(d.output, {{x}}))
